@@ -19,46 +19,13 @@ from sklearn.metrics import accuracy_score, roc_auc_score, mean_squared_error
 
 from nanome.common.eval_common import *
 from nanome.common.global_settings import NANOME_VERSION, save_done_file, \
-    region_filename_dict
+    region_filename_dict, DEFAULT_SCORE_CUTOFF_BY_TOOLS
 
 SITE_COLUMNS = ['Chr', 'Pos', 'Strand']
 READ_COLUMNS = ['ID'] + SITE_COLUMNS
 
-DTYPE = {'ID': str, 'Chr': str, 'Pos': int, 'Strand': str,
-         'Freq': float, 'Coverage': int}
-
-
-def prob_to_llr_2(meth_prob):
-    """
-    METEORE, NANOME manner
-    Args:
-        meth_prob:
-
-    Returns:
-
-    """
-    return math.log2((meth_prob + EPSLONG) / (1 - meth_prob + EPSLONG))
-
-
-def prob_to_llr_e(meth_prob):
-    """
-    Megalodon manner:
-    prob_to_llr_2(0.8)
-    1.999945900626566
-    prob_to_llr_e(0.8)
-    1.3862568622917248
-
-    Args:
-        meth_prob:
-
-    Returns:
-
-    """
-    return math.log((meth_prob + EPSLONG) / (1 - meth_prob + EPSLONG))
-
-
-DEFAULT_CUTOFF_MEGALODON = prob_to_llr_e(0.8)
-DEFAULT_CUTOFF_NANOPOLISH = 2
+DTYPE_BASIC_DF = {'ID': str, 'Chr': str, 'Pos': int, 'Strand': str,
+                  'Freq': float, 'Coverage': int}
 
 
 def update_progress_bar_join_preds_eval(*a):
@@ -246,6 +213,7 @@ def find_join_preds_bgtruth_as_df(dsname, chrs, db_dir, cutoffDict, dtype=None,
     Returns:
 
     """
+    logger.debug(f"Find joined preds db at: {db_dir}")
     find_files = []
     for chr in chrs:
         fnlist = glob.glob(os.path.join(db_dir, '**', f'{dsname}_T*_{chr}_join_preds_eval_db.sort.csv.gz'),
@@ -257,7 +225,7 @@ def find_join_preds_bgtruth_as_df(dsname, chrs, db_dir, cutoffDict, dtype=None,
                 f"Found more than one file for {chr} for {dsname} at {db_dir}: {fnlist}, we use only first one.")
         if len(fnlist) >= 1:
             find_files.append(fnlist[0])
-    logger.debug(f"find_files={find_files}, len={len(find_files)}")
+    logger.debug(f"find_files[0]={find_files[0]}, len={len(find_files)}")
 
     dflist = []
     for infn in find_files:
@@ -529,7 +497,7 @@ def parse_arguments():
     parser.add_argument('--chrs', nargs='+', type=str, help='chromosome list, default is human chr1-22, X and Y',
                         default=HUMAN_CHR_SET)
     parser.add_argument('--score-cutoff', nargs='+', type=float,
-                        help='cutoff of LLR score for listed tool in --calls, default is used for all/not specified',
+                        help='cutoff of LLR score for listed tool in --calls, default is used for all/not specified. This cutoff only used in evaluation, not in make preds db step.',
                         default=None)
     parser.add_argument('--fully-meth-threshold', type=float, default=1.0,
                         help='fully methylated threshold (e.g., 0.9) for selection CpGs for read-level evaluation, default is 1.0')
@@ -559,18 +527,21 @@ def parse_arguments():
 
 
 if __name__ == '__main__':
-    args = parse_arguments()
+    global progress_bar_global_join_preds
 
+    args = parse_arguments()
     if args.verbose:
         set_log_debug_level()
     else:
         set_log_info_level()
 
-    logger.debug(f"args={args}")
-
     out_dir = os.path.join(args.o, args.runid)
     os.makedirs(out_dir, exist_ok=True)
 
+    # Add logging files also to result output dir
+    add_logging_file(os.path.join(out_dir, f'run-results-{current_time_str()}.log'))
+    logger.debug(f"args={args}")
+
     bed_temp_dir = os.path.join(args.bedtools_tmp, f"{args.dsname}_join_preds")
     os.makedirs(bed_temp_dir, exist_ok=True)
     pybedtools.helpers.set_tempdir(bed_temp_dir)
@@ -579,21 +550,21 @@ if __name__ == '__main__':
     callDict = {}
     for callStr in args.calls:
         toolName, toolFile = callStr.strip().split(':')
+        if len(toolFile.strip()) < 1:
+            continue
         callDict[toolName.lower()] = toolFile
+    # cutoff only used for evalutation, not used for make preds db step
     cutoffDict = {}
     for ind, toolName in enumerate(callDict.keys()):
         if args.score_cutoff is not None and ind < len(args.score_cutoff):  # preset cutoff
             cutoffDict[toolName] = args.score_cutoff[ind]
         else:  # default values
-            if toolName.lower() == 'nanopolish':
-                cutoffDict[toolName] = DEFAULT_CUTOFF_NANOPOLISH
-            elif toolName.lower() == 'megalodon':
-                cutoffDict[toolName] = DEFAULT_CUTOFF_MEGALODON
+            if toolName in DEFAULT_SCORE_CUTOFF_BY_TOOLS:
+                cutoffDict[toolName] = DEFAULT_SCORE_CUTOFF_BY_TOOLS[toolName]
             else:
+                # means no cutoff
                 cutoffDict[toolName] = 0.0
-    logger.debug(f"callDict={callDict}, cutoffDict={cutoffDict}")
-
-    global progress_bar_global_join_preds
+    logger.info(f"callDict={callDict}, cutoffDict={cutoffDict}")
 
     if args.join_preds:
         logger.info("Join preds of bs-seq with tool, take times...")
@@ -637,13 +608,13 @@ if __name__ == '__main__':
         logger.info(f"### DONE for make joined prediction db.")
     else:
         logger.info(
-            f"Assume you have generated all joined preds db at:{out_dir} or {args.dbdir}, make sure this is correct if you skip make predictions joined db by --skip-join-preds.")
+            f"Assume you have generated all joined preds db at:{out_dir} or {args.dbdir}, make sure this is correct if you skip make predictions joined db by skip option: --join-preds.")
 
     ## Step 2: read level eval on joined preds
-    new_dtype = dict(DTYPE)
+    new_dtype = dict(DTYPE_BASIC_DF)
     for toolName in callDict:
         new_dtype.update({toolName: float})
-    logger.debug(f"new_dtype={new_dtype}")
+    # logger.debug(f"new_dtype={new_dtype}")
 
     if args.read_eval or args.site_eval:
         if args.region_report:
